==> mdm-rpc-0.0.30-sources.jar: com/chinayanghe/msp/mdm/vo/org/OrgAreaVo.java <==
package com.chinayanghe.msp.mdm.vo.org;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by Administrator on 2017/5/31 0031.
 */
public class OrgAreaVo implements Serializable{
    private static final long serialVersionUID = 5193684238523368263L;
    //主键
    private String id;
    //组织编码
    private String orgCode;
    //省
    private String provinceCode;
    //市
    private String cityCode;
    //县区
    private String countryCode;
    //镇
    private String townCode;
    //有效开始时间
    private Date validStartDate;
    //有效结束时间
    private Date validEndDate;
    //启用状态：0-启用，1-不启用
    private int enableStatus;
    //创建时间
    private Date createDate;
    //创建人
    private String createName;
    //岗位ID
    private String orgId;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public String getProvinceCode() {
        return provinceCode;
    }

    public void setProvinceCode(String provinceCode) {
        this.provinceCode = provinceCode;
    }

    public String getCityCode() {
        return cityCode;
    }

    public void setCityCode(String cityCode) {
        this.cityCode = cityCode;
    }

    public String getCountryCode() {
        return countryCode;
    }

    public void setCountryCode(String countryCode) {
        this.countryCode = countryCode;
    }

    public String getTownCode() {
        return townCode;
    }

    public void setTownCode(String townCode) {
        this.townCode = townCode;
    }

    public Date getValidStartDate() {
        return validStartDate;
    }

    public void setValidStartDate(Date validStartDate) {
        this.validStartDate = validStartDate;
    }

    public Date getValidEndDate() {
        return validEndDate;
    }

    public void setValidEndDate(Date validEndDate) {
        this.validEndDate = validEndDate;
    }

    public int getEnableStatus() {
        return enableStatus;
    }

    public void setEnableStatus(int enableStatus) {
        this.enableStatus = enableStatus;
    }

    public Date getCreateDate() {
        return createDate;
    }

    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    public String getCreateName() {
        return createName;
    }

    public void setCreateName(String createName) {
        this.createName = createName;
    }

    public String getOrgId() {
        return orgId;
    }

    public void setOrgId(String orgId) {
        this.orgId = orgId;
    }
}

==> mdm-rpc-0.1.14-sources.jar: com/chinayanghe/msp/mdm/vo/org/OrgAreaVo.java <==
package com.chinayanghe.msp.mdm.vo.org;

import java.util.Date;

/**
 * Created by Administrator on 2017/5/31 0031.
 */
public class OrgAreaVo {
    //主键
    private String id;
    //组织编码
    private String orgCode;
    //省
    private String provinceCode;
    //市
    private String cityCode;
    //县区
    private String countryCode;
    //镇
    private String townCode;
    //有效开始时间
    private Date validStartDate;
    //有效结束时间
    private Date validEndDate;
    //启用状态：0-启用，1-不启用
    private int enableStatus;
    //创建时间
    private Date createDate;
    //创建人
    private String createName;
    //岗位ID
    private String orgId;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public String getProvinceCode() {
        return provinceCode;
    }

    public void setProvinceCode(String provinceCode) {
        this.provinceCode = provinceCode;
    }

    public String getCityCode() {
        return cityCode;
    }

    public void setCityCode(String cityCode) {
        this.cityCode = cityCode;
    }

    public String getCountryCode() {
        return countryCode;
    }

    public void setCountryCode(String countryCode) {
        this.countryCode = countryCode;
    }

    public String getTownCode() {
        return townCode;
    }

    public void setTownCode(String townCode) {
        this.townCode = townCode;
    }

    public Date getValidStartDate() {
        return validStartDate;
    }

    public void setValidStartDate(Date validStartDate) {
        this.validStartDate = validStartDate;
    }

    public Date getValidEndDate() {
        return validEndDate;
    }

    public void setValidEndDate(Date validEndDate) {
        this.validEndDate = validEndDate;
    }

    public int getEnableStatus() {
        return enableStatus;
    }

    public void setEnableStatus(int enableStatus) {
        this.enableStatus = enableStatus;
    }

    public Date getCreateDate() {
        return createDate;
    }

    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    public String getCreateName() {
        return createName;
    }

    public void setCreateName(String createName) {
        this.createName = createName;
    }

    public String getOrgId() {
        return orgId;
    }

    public void setOrgId(String orgId) {
        this.orgId = orgId;
    }
}
